package com.example.radum.supertrackernative;

import android.Manifest;
import android.content.SharedPreferences;
import android.graphics.Color;
import android.support.v4.app.ActivityCompat;
import android.support.v4.app.FragmentActivity;
import android.os.Bundle;
import android.test.mock.MockPackageManager;

import com.google.android.gms.maps.CameraUpdateFactory;
import com.google.android.gms.maps.GoogleMap;
import com.google.android.gms.maps.OnMapReadyCallback;
import com.google.android.gms.maps.SupportMapFragment;
import com.google.android.gms.maps.model.BitmapDescriptorFactory;
import com.google.android.gms.maps.model.LatLng;
import com.google.android.gms.maps.model.Marker;
import com.google.android.gms.maps.model.MarkerOptions;
import com.google.android.gms.maps.model.Polyline;
import com.google.android.gms.maps.model.PolylineOptions;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.List;

public class MapsActivity extends FragmentActivity implements OnMapReadyCallback {
    public GoogleMap gMap;
    public Marker gMarker=null;
    public Polyline gPolyline=null;

    public List<LatLng> gRoute;
    public List<List<LatLng>> gCollection;
    public int gCollectionIndex=0;

    private LocationHandler gLocationHandler;
    private Controls gControls;

    public enum ScreenType {
        MAIN, TRACKING, PUBLISHING, COLLECTION
    }
    public ScreenType gScreen=ScreenType.MAIN;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_maps);
        // Obtain the SupportMapFragment and get notified when the map is ready to be used.
        SupportMapFragment mapFragment = (SupportMapFragment) getSupportFragmentManager()
                .findFragmentById(R.id.map);
        mapFragment.getMapAsync(this);

        try{
            if (ActivityCompat.checkSelfPermission(this,
                    Manifest.permission.ACCESS_FINE_LOCATION)
                    != MockPackageManager.PERMISSION_GRANTED) {

                ActivityCompat.requestPermissions(this, new String[]{
                                Manifest.permission.ACCESS_FINE_LOCATION
                        },
                        2);
            }else{
                // everything ok with permissions

                gLocationHandler = new LocationHandler(MapsActivity.this);
                if(gLocationHandler.location==null){
                    // warn that location setting is off
                    gLocationHandler.showSettingsAlert();
                }else{
                    // Success got the location
                }

            }
        } catch (Exception e) {
            e.printStackTrace();
        }

        gRoute=new ArrayList<LatLng>();
        gCollection=new ArrayList<List<LatLng>>();
        tryLoadCollection();

        gControls =new Controls(this);
        gControls.addEventListeners();
        gControls.initControls();


    }

    /**
     * Manipulates the map once available.
     * This callback is triggered when the map is ready to be used.
     * This is where we can add markers or lines, add listeners or move the camera. In this case,
     * we just add a marker near Sydney, Australia.
     * If Google Play services is not installed on the device, the user will be prompted to install
     * it inside the SupportMapFragment. This method will only be triggered once the user has
     * installed Google Play services and returned to the app.
     */
    @Override
    public void onMapReady(GoogleMap googleMap) {
        LatLng defaultLocation = new LatLng(62, 28);
        gMap = googleMap;

        MarkerOptions mo = new MarkerOptions();
        mo.position(defaultLocation);
        mo.icon(BitmapDescriptorFactory.fromResource(R.raw.sup));
        mo.anchor(0.5f, 0.5f);

        gMarker = gMap.addMarker(mo);
        gPolyline = gMap.addPolyline(new PolylineOptions()
                .width(5)
                .color(Color.RED));
        gMap.moveCamera(CameraUpdateFactory.newLatLngZoom(defaultLocation, 65));
    }


    private void tryLoadCollection(){
        SharedPreferences prefs = getSharedPreferences("MyPrefsFile", MODE_PRIVATE);
        String restoredText = prefs.getString("name", null);
        JSONArray jsonlocations=new JSONArray();


        if (restoredText != null) {
            String name = prefs.getString("name", String.valueOf(new JSONArray()));//"No name defined" is the default value.
            try {
                jsonlocations=new JSONArray(name);
                for(int i=0;i<jsonlocations.length();i++){
                    ArrayList<LatLng> route=new ArrayList<LatLng>();
                    JSONArray joa=jsonlocations.getJSONArray(i);
                    for(int j=0;j<joa.length();j++){
                        route.add(new LatLng(Double.parseDouble(joa.getJSONObject(j).get("lat").toString()),
                                Double.parseDouble(joa.getJSONObject(j).get("lng").toString())));
                    }
                    gCollection.add(route);
                    //jsonlocations.getJSONObject(i).get("lat")
                }
            } catch (JSONException e) {
                e.printStackTrace();
            }
        }
    }

    public void saveCollection(){
        try{
            JSONArray jsonlocations=new JSONArray();
            for(int i=0;i<gCollection.size();i++) {
                JSONArray route = new JSONArray();
                for (int j = 0; j < gCollection.get(i).size(); j++) {
                    JSONObject jo = new JSONObject();
                    jo.put("lat", gCollection.get(i).get(j).latitude);
                    jo.put("lng", gCollection.get(i).get(j).longitude);
                    route.put(jo);
                }
                jsonlocations.put(route);
            }
            SharedPreferences.Editor editor = getSharedPreferences("MyPrefsFile", MODE_PRIVATE).edit();
            editor.putString("name", String.valueOf(jsonlocations));
            editor.commit();
        }catch(Exception e){
        }
    }

}
